==> calligra_2.8.1-1.orig.tar.xz: calligra-2.8.1/stage/part/tools/KPrPlaceholderTool.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KPRPLACEHOLDERTOOL_H
#define KPRPLACEHOLDERTOOL_H

#include <KoToolBase.h>

class KPrPlaceholderTool : public KoToolBase
{
    Q_OBJECT
public:
    explicit KPrPlaceholderTool(KoCanvasBase *canvas);
    virtual ~KPrPlaceholderTool();

    virtual void paint( QPainter &painter, const KoViewConverter &converter );

    virtual void mousePressEvent( KoPointerEvent *event );
    virtual void mouseMoveEvent( KoPointerEvent *event );
    virtual void mouseReleaseEvent( KoPointerEvent *event );

public slots:
    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
};

#endif /* KPRPLACEHOLDERTOOL_H */

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/part/tools/KPrPlaceholderTool.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KPRPLACEHOLDERTOOL_H
#define KPRPLACEHOLDERTOOL_H

#include <KoToolBase.h>

class KPrPlaceholderTool : public KoToolBase
{
    Q_OBJECT
public:
    explicit KPrPlaceholderTool(KoCanvasBase *canvas);
    ~KPrPlaceholderTool() override;

    void paint( QPainter &painter, const KoViewConverter &converter ) override;

    void mousePressEvent( KoPointerEvent *event ) override;
    void mouseMoveEvent( KoPointerEvent *event ) override;
    void mouseReleaseEvent( KoPointerEvent *event ) override;

public Q_SLOTS:
    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
};

#endif /* KPRPLACEHOLDERTOOL_H */
